@@ -19,8 +19,8 @@
 #define H2CORE_VERSION_MINOR 2
 #define H2CORE_VERSION_PATCH 6
 
-#define H2CORE_GIT_REVISION 'd2a48011b'
-#define H2CORE_VERSION "1.2.6-'d2a48011b'"
+#define H2CORE_GIT_REVISION 
+#define H2CORE_VERSION "1.2.6-"
 #define H2CORE_IS_DEVEL_BUILD true
 
 
@@ -36,7 +36,7 @@
 #define HAVE_EXECINFO_H
 
 #ifndef H2CORE_HAVE_DEBUG
-#define H2CORE_HAVE_DEBUG
+/* #undef H2CORE_HAVE_DEBUG */
 #endif
 #ifndef H2CORE_HAVE_QT6
 #define H2CORE_HAVE_QT6
